==> bingads-9.3.1.zip: bingads-9.3.1/bingads/internal/bulk/string_table.py <==
class _StringTable:
    # CSV Header Strings
    ClientId = "Client Id"
    Type = "Type"
    Status = "Status"
    Campaign = "Campaign"
    Id = "Id"
    BusinessId = "Business Id"
    ParentId = "Parent Id"
    TimeZone = "Time Zone"
    Budget = "Budget"
    BudgetType = "Budget Type"
    KeywordVariantMatchEnabled = "KeywordVariantMatchEnabled"
    AdGroup = "Ad Group"
    Keyword = "Keyword"
    TextAd = "Text Ad"
    MobileAd = "Mobile Ad"
    ProductAd = "Product Ad"
    Title = "Title"
    EditorialStatus = "Editorial Status"
    EditorialAppealStatus = "Editorial Appeal Status"
    Error = "Error"
    ErrorNumber = "Error Number"
    EditorialLocation = "Editorial Location"
    EditorialTerm = "Editorial Term"
    EditorialReasonCode = "Editorial Reason Code"
    MigrationErrors = "Migration Errors"
    DisplayUrl = "Display Url"
    DestinationUrl = "Destination Url"
    BusinessName = "Business Name"
    PhoneNumber = "Phone Number"
    PromotionalText = "Promotion"
    MatchType = "Match Type"
    Param1 = "Param1"
    Param2 = "Param2"
    Param3 = "Param3"
    DevicePreference = "Device Preference"
    CampaignNegativeKeyword = "Campaign Negative Keyword"
    CampaignNegativeSite = "Campaign Negative Site"
    AdGroupNegativeKeyword = "Ad Group Negative Keyword"
    KeywordNegativeKeyword = "Keyword Negative Keyword"
    AdGroupNegativeSite = "Ad Group Negative Site"
    Text = "Text"
    Website = "Website"
    Target = "Target"
    PhysicalIntent = "Physical Intent"
    Bid = "Bid"
    BidAdjustment = "Bid Adjustment"
    SubType = "Sub Type"
    OsNames = "OS Names"
    StartDate = "Start Date"
    EndDate = "End Date"
    NetworkDistribution = "Network Distribution"
    SearchNetwork = "Search Network"
    ContentNetwork = "Content Network"
    PricingModel = "Pricing Model"
    Language = "Language"
    SearchBroadBid = "Search Broad Bid"
    ContentBid = "Content Bid"
    AdRotation = "Ad Rotation"
    Account = "Account"
    SyncTime = "Sync Time"
    Name = "Name"
    LastModifiedTime = "Modified Time"

    # Entity Types
    SemanticVersion = "Format Version"
    LocationTarget = "Location Target"
    RadiusTarget = "Radius Target"
    BusinessTarget = "Business Location Target"
    RadiusTargetId = "Radius Target Id"
    NegativeLocationTarget = "Negative Location Target"
    AgeTarget = "Age Target"
    GenderTarget = "Gender Target"
    DayTarget = "Day Target"
    HourTarget = "Hour Target"
    DeviceOsTarget = "DeviceOS Target"
    Radius = "Radius"
    Unit = "Unit"
    TargetAll = "Target All"
    SiteLinksAdExtension = "Sitelink Ad Extension"
    LocationAdExtension = "Location Ad Extension"
    ProductAdExtension = "Product Ad Extension"
    CallAdExtension = "Call Ad Extension"
    ImageAdExtension = "Image Ad Extension"
    SocialNetworkAdExtension = "Social Network Ad Extension"
    Version = "Version"

    # Image AdExtension
    AltText = "Alternative Text"
    MediaId = "Media Id"
    CampaignImageAdExtension = "Campaign Image Ad Extension"
    AdGroupImageAdExtension = "Ad Group Image Ad Extension"

    # SiteLink AdExtensions
    SiteLinkExtensionOrder = "Sitelink Extension Order"
    SiteLinkDisplayText = "Sitelink Extension Link Text"
    SiteLinkDestinationUrl = "Sitelink Extension Destination Url"
    SiteLinkDescription1 = "Sitelink Extension Description1"
    SiteLinkDescription2 = "Sitelink Extension Description2"
    CampaignSiteLinksAdExtension = "Campaign Sitelink Ad Extension"
    AdGroupSiteLinksAdExtension = "AdGroup Sitelink Ad Extension"

    # Location AdExtensions
    AddressLine1 = "Address Line 1"
    AddressLine2 = "Address Line 2"
    PostalCode = "Postal Code"
    City = "City"
    StateOrProvince = "State Or Province Code"
    ProvinceName = "Province Name"
    GeoCodeStatus = "Geo Code Status"
    IconMediaId = "Map Icon"
    ImageMediaId = "Business Icon"
    CampaignLocationAdExtension = "Campaign Location Ad Extension"

    # Call AdExtensions
    CountryCode = "COUNTRY_CODE"
    IsCallOnly = "Call Only"
    CampaignCallAdExtension = "Campaign Call Ad Extension"
    IsCallTrackingEnabled = "Call Tracking Enabled"
    RequireTollFreeTrackingNumber = "Toll Free"

    # Editorial Rejection Reasons
    PublisherCountries = "Publisher Countries"

    # Product Target
    ProductTargetType = "Ad Group Product Target"
    ProductCondition1 = "Product Condition 1"
    ProductCondition2 = "Product Condition 2"
    ProductCondition3 = "Product Condition 3"
    ProductValue1 = "Product Value 1"
    ProductValue2 = "Product Value 2"
    ProductValue3 = "Product Value 3"

    # BTE Types
    KeywordFirstPageBidType = "Keyword First Page Bid"
    KeywordMainLineBidType = "Keyword Main Line Bid"
    KeywordBestPositionBidType = "Keyword Best Position Bid"

    # Product AdExtension
    CampaignProductAdExtension = "Campaign Product Ad Extension"
    ProductCondition4 = "Product Condition 4"
    ProductCondition5 = "Product Condition 5"
    ProductCondition6 = "Product Condition 6"
    ProductCondition7 = "Product Condition 7"
    ProductCondition8 = "Product Condition 8"
    ProductValue4 = "Product Value 4"
    ProductValue5 = "Product Value 5"
    ProductValue6 = "Product Value 6"
    ProductValue7 = "Product Value 7"
    ProductValue8 = "Product Value 8"
    BingMerchantCenterId = "Store Id"
    BingMerchantCenterName = "Store Name"

    # Misc Stuff
    EntityActiveStatus = "Active"
    EntityDeletedStatus = "Deleted"
    IntraFieldSeparator = ';'
    Active = "Active"
    Latitude = "Latitude"
    Longitude = "Longitude"

    # BI
    Spend = "Spend"
    Impressions = "Impressions"
    Clicks = "Clicks"
    CTR = "CTR"
    AvgCPC = "Avg CPC"
    AvgCPM = "Avg CPM"
    AvgPosition = "Avg position"
    Conversions = "Conversions"
    CPA = "CPA"
    QualityScore = "Quality Score"
    KeywordRelevance = "Keyword Relevance"
    LandingPageRelevance = "Landing Page Relevance"
    LandingPageUserExperience = "Landing Page User Experience"

    # DayTime Target
    DayTimeTarget = "DayTime Target"
    FromHour = "From Hour"
    ToHour = "To Hour"
    FromMinute = "From Minute"
    ToMinute = "To Minute"

    # Shared Entities
    NegativeKeywordList = "Negative Keyword List"
    CampaignNegativeKeywordList = "Campaign Negative Keyword List Association"
    ListNegativeKeyword = "Shared Negative Keyword"

    # Subtypes
    MetroAreaSubType = "Metro Area"
    CountrySubType = "Country"
    StateSubType = "State"
    CitySubType = "City"
    PostalCodeSubType = "Postal Code"

==> bingads-9.3.2.zip: bingads-9.3.2/bingads/internal/bulk/string_table.py <==
class _StringTable:
    # CSV Header Strings
    ClientId = "Client Id"
    Type = "Type"
    Status = "Status"
    Campaign = "Campaign"
    Id = "Id"
    BusinessId = "Business Id"
    ParentId = "Parent Id"
    TimeZone = "Time Zone"
    Budget = "Budget"
    BudgetType = "Budget Type"
    KeywordVariantMatchEnabled = "KeywordVariantMatchEnabled"
    AdGroup = "Ad Group"
    Keyword = "Keyword"
    TextAd = "Text Ad"
    MobileAd = "Mobile Ad"
    ProductAd = "Product Ad"
    Title = "Title"
    EditorialStatus = "Editorial Status"
    EditorialAppealStatus = "Editorial Appeal Status"
    Error = "Error"
    ErrorNumber = "Error Number"
    EditorialLocation = "Editorial Location"
    EditorialTerm = "Editorial Term"
    EditorialReasonCode = "Editorial Reason Code"
    MigrationErrors = "Migration Errors"
    DisplayUrl = "Display Url"
    DestinationUrl = "Destination Url"
    BusinessName = "Business Name"
    PhoneNumber = "Phone Number"
    PromotionalText = "Promotion"
    MatchType = "Match Type"
    Param1 = "Param1"
    Param2 = "Param2"
    Param3 = "Param3"
    DevicePreference = "Device Preference"
    CampaignNegativeKeyword = "Campaign Negative Keyword"
    CampaignNegativeSite = "Campaign Negative Site"
    AdGroupNegativeKeyword = "Ad Group Negative Keyword"
    KeywordNegativeKeyword = "Keyword Negative Keyword"
    AdGroupNegativeSite = "Ad Group Negative Site"
    Text = "Text"
    Website = "Website"
    Target = "Target"
    PhysicalIntent = "Physical Intent"
    Bid = "Bid"
    BidAdjustment = "Bid Adjustment"
    SubType = "Sub Type"
    OsNames = "OS Names"
    StartDate = "Start Date"
    EndDate = "End Date"
    NetworkDistribution = "Network Distribution"
    SearchNetwork = "Search Network"
    ContentNetwork = "Content Network"
    PricingModel = "Pricing Model"
    Language = "Language"
    SearchBroadBid = "Search Broad Bid"
    ContentBid = "Content Bid"
    AdRotation = "Ad Rotation"
    Account = "Account"
    SyncTime = "Sync Time"
    Name = "Name"
    LastModifiedTime = "Modified Time"

    # Entity Types
    SemanticVersion = "Format Version"
    LocationTarget = "Location Target"
    RadiusTarget = "Radius Target"
    BusinessTarget = "Business Location Target"
    RadiusTargetId = "Radius Target Id"
    NegativeLocationTarget = "Negative Location Target"
    AgeTarget = "Age Target"
    GenderTarget = "Gender Target"
    DayTarget = "Day Target"
    HourTarget = "Hour Target"
    DeviceOsTarget = "DeviceOS Target"
    Radius = "Radius"
    Unit = "Unit"
    TargetAll = "Target All"
    SiteLinksAdExtension = "Sitelink Ad Extension"
    LocationAdExtension = "Location Ad Extension"
    ProductAdExtension = "Product Ad Extension"
    CallAdExtension = "Call Ad Extension"
    ImageAdExtension = "Image Ad Extension"
    SocialNetworkAdExtension = "Social Network Ad Extension"
    Version = "Version"

    # Image AdExtension
    AltText = "Alternative Text"
    MediaId = "Media Id"
    CampaignImageAdExtension = "Campaign Image Ad Extension"
    AdGroupImageAdExtension = "Ad Group Image Ad Extension"

    # SiteLink AdExtensions
    SiteLinkExtensionOrder = "Sitelink Extension Order"
    SiteLinkDisplayText = "Sitelink Extension Link Text"
    SiteLinkDestinationUrl = "Sitelink Extension Destination Url"
    SiteLinkDescription1 = "Sitelink Extension Description1"
    SiteLinkDescription2 = "Sitelink Extension Description2"
    CampaignSiteLinksAdExtension = "Campaign Sitelink Ad Extension"
    AdGroupSiteLinksAdExtension = "AdGroup Sitelink Ad Extension"

    # Location AdExtensions
    AddressLine1 = "Address Line 1"
    AddressLine2 = "Address Line 2"
    PostalCode = "Postal Code"
    City = "City"
    StateOrProvince = "State Or Province Code"
    ProvinceName = "Province Name"
    GeoCodeStatus = "Geo Code Status"
    IconMediaId = "Map Icon"
    ImageMediaId = "Business Icon"
    CampaignLocationAdExtension = "Campaign Location Ad Extension"

    # Call AdExtensions
    CountryCode = "COUNTRY_CODE"
    IsCallOnly = "Call Only"
    CampaignCallAdExtension = "Campaign Call Ad Extension"
    IsCallTrackingEnabled = "Call Tracking Enabled"
    RequireTollFreeTrackingNumber = "Toll Free"

    # Editorial Rejection Reasons
    PublisherCountries = "Publisher Countries"

    # Product Target
    ProductTargetType = "Ad Group Product Target"
    ProductCondition1 = "Product Condition 1"
    ProductCondition2 = "Product Condition 2"
    ProductCondition3 = "Product Condition 3"
    ProductValue1 = "Product Value 1"
    ProductValue2 = "Product Value 2"
    ProductValue3 = "Product Value 3"

    # BTE Types
    KeywordFirstPageBidType = "Keyword First Page Bid"
    KeywordMainLineBidType = "Keyword Main Line Bid"
    KeywordBestPositionBidType = "Keyword Best Position Bid"

    # Product AdExtension
    CampaignProductAdExtension = "Campaign Product Ad Extension"
    ProductCondition4 = "Product Condition 4"
    ProductCondition5 = "Product Condition 5"
    ProductCondition6 = "Product Condition 6"
    ProductCondition7 = "Product Condition 7"
    ProductCondition8 = "Product Condition 8"
    ProductValue4 = "Product Value 4"
    ProductValue5 = "Product Value 5"
    ProductValue6 = "Product Value 6"
    ProductValue7 = "Product Value 7"
    ProductValue8 = "Product Value 8"
    BingMerchantCenterId = "Store Id"
    BingMerchantCenterName = "Store Name"

    # App Ad Extension
    AppAdExtension = "App Ad Extension"
    AppPlatform = "App Platform"
    AppStoreId = "App Id"
    CampaignAppAdExtension = "Campaign App Ad Extension"
    AdGroupAppAdExtension = "Ad Group App Ad Extension"
    IsTrackingEnabled = "Tracking Enabled"

    # Misc Stuff
    EntityActiveStatus = "Active"
    EntityDeletedStatus = "Deleted"
    IntraFieldSeparator = ';'
    Active = "Active"
    Latitude = "Latitude"
    Longitude = "Longitude"

    # BI
    Spend = "Spend"
    Impressions = "Impressions"
    Clicks = "Clicks"
    CTR = "CTR"
    AvgCPC = "Avg CPC"
    AvgCPM = "Avg CPM"
    AvgPosition = "Avg position"
    Conversions = "Conversions"
    CPA = "CPA"
    QualityScore = "Quality Score"
    KeywordRelevance = "Keyword Relevance"
    LandingPageRelevance = "Landing Page Relevance"
    LandingPageUserExperience = "Landing Page User Experience"

    # DayTime Target
    DayTimeTarget = "DayTime Target"
    FromHour = "From Hour"
    ToHour = "To Hour"
    FromMinute = "From Minute"
    ToMinute = "To Minute"

    # Shared Entities
    NegativeKeywordList = "Negative Keyword List"
    CampaignNegativeKeywordList = "Campaign Negative Keyword List Association"
    ListNegativeKeyword = "Shared Negative Keyword"

    # Subtypes
    MetroAreaSubType = "Metro Area"
    CountrySubType = "Country"
    StateSubType = "State"
    CitySubType = "City"
    PostalCodeSubType = "Postal Code"
